@@ -4,7 +4,7 @@
 
 from __future__ import annotations
 
-from typing import Any, Generator, TYPE_CHECKING
+from typing import Any, Generator, TYPE_CHECKING, TypeVar
 
 # ┌─────────────────────────────────────────────────────────────────────────────────────
 # │ PROJECT IMPORTS
@@ -20,6 +20,12 @@ if TYPE_CHECKING:
     from core.collections.classes.items import Items
     from core.types import JSONSchema
 
+# ┌─────────────────────────────────────────────────────────────────────────────────────
+# │ TYPE VARIABLES
+# └─────────────────────────────────────────────────────────────────────────────────────
+
+T = TypeVar("T", bound="Item")
+
 
 # ┌─────────────────────────────────────────────────────────────────────────────────────
 # │ ITEM
@@ -57,7 +63,22 @@ class Item(metaclass=ItemMetaclass):
                 return True
 
         # Call super method
-        return super().__eq__(other)
+        return False
+
+    # ┌─────────────────────────────────────────────────────────────────────────────────
+    # │ __HASH__
+    # └─────────────────────────────────────────────────────────────────────────────────
+
+    def __hash__(self) -> int:
+        """Hash Method"""
+
+        # Check if item has an ID
+        if self._imeta.id is not None:
+            # Return hash of ID
+            return hash(self.__class__) ^ hash(self._imeta.id)
+
+        # Otherwise return hash of item ID in memory
+        return hash(id(self))
 
     # ┌─────────────────────────────────────────────────────────────────────────────────
     # │ __REPR__
@@ -116,7 +137,7 @@ class Item(metaclass=ItemMetaclass):
     # └─────────────────────────────────────────────────────────────────────────────────
 
     @classmethod
-    def from_dict(cls: type[Item], data: dict[Any, Any]) -> Item:
+    def from_dict(cls: type[T], data: dict[Any, Any]) -> T:
         """Initializes an item from a dictionary"""
 
         # Initialize and return item
@@ -128,11 +149,11 @@ class Item(metaclass=ItemMetaclass):
 
     @classmethod
     def from_json(
-        cls: type[Item],
+        cls: type[T],
         data: Any,
         path: str | None = None,
         schema: JSONSchema | None = None,
-    ) -> Generator[Item, None, None]:
+    ) -> Generator[T, None, None]:
         """Yields items from a list of dictionaries"""
 
         # Yield from JSON object
